@@ -32,7 +32,10 @@ class DeltaProvider:
         for i in self.me.module.get_all():
             #Maybe we should be unicode....
             assert type(i) in [str,unicode], "LUID Must be str not %s" % type(i)
-            allItems.append(i)
+            #Make sure the are in unicode to assure good comparison with mapping UID's
+            #FIXME: Replace or ignore non unicode chars?
+            allItems.append(unicode(i,errors='replace'))
+
         log.debug("Delta: Got %s items\n%s" % (len(allItems), allItems))
 
         #In order to detect deletions we need to fetch all the existing relationships.
@@ -64,4 +67,3 @@ class DeltaProvider:
         #and all that remains in allItems is new data
         return allItems, modified, rids.keys()
 
-
