@@ -1,5 +1,6 @@
 import os.path
 import logging
+import ConfigParser
 log = logging.getLogger("dataproviders.File")
 
 import conduit
@@ -8,10 +9,64 @@ import conduit.datatypes as DataType
 import conduit.datatypes.File as File
 import conduit.Vfs as Vfs
 import conduit.Database as DB
+import conduit.Exceptions as Exceptions
 
 TYPE_FILE = "0"
 TYPE_FOLDER = "1"
 
+def is_on_removable_volume(folderUri):
+    return Vfs.uri_is_on_removable_volume(folderUri)
+    
+def get_removable_volume_info(folderUri):
+    """
+    Returns the root uri of the volume, and local path of the 
+    group config file
+    """
+    rooturi = Vfs.uri_get_volume_root_uri(folderUri)
+    path = Vfs.uri_join(
+                Vfs.uri_to_local_path(rooturi),
+                ".conduit")
+    return rooturi,path
+    
+def save_removable_volume_group_file(folderUri, folderGroupName):
+    if is_on_removable_volume(folderUri):
+        #write to the /volume/root/.conduit file
+        rooturi,path = get_removable_volume_info(folderUri)
+        fp = open(path, "w+r")
+        conf = ConfigParser.SafeConfigParser()
+        conf.readfp(fp)
+        #save the relative path, and the group name
+        #in INI format
+        #
+        #[DEFAULT]
+        #relative/uri/from/volume/root = group name
+        #
+        log.debug("Saving group (%s = %s) to %s" % (folderUri,folderGroupName,path))
+        conf.set(
+            "DEFAULT",
+            folderUri.replace(rooturi,""),
+            folderGroupName
+            )
+        conf.write(fp)
+        fp.close()
+        return True
+    return False
+
+def read_removable_volume_group_file(folderUri):
+    if is_on_removable_volume(folderUri):
+        #read from the /volume/root/.conduit file
+        rooturi,path = get_removable_volume_info(folderUri)
+        if Vfs.uri_exists(path):
+            conf = ConfigParser.SafeConfigParser()
+            fp = open(path, "r")
+            conf.readfp(fp)
+            items = conf.items("DEFAULT")
+            fp.close()                
+            for i,j in items:
+                log.debug("Read group (%s = %s)" % (i,j))
+            return items
+    return ()
+
 class FileSource(DataProvider.DataSource, Vfs.FolderScannerThreadManager):
 
     _category_ = conduit.dataproviders.CATEGORY_FILES
@@ -165,25 +220,29 @@ class FolderTwoWay(DataProvider.TwoWay):
 
     def __init__(self, folder, folderGroupName, includeHidden, compareIgnoreMtime):
         DataProvider.TwoWay.__init__(self)
-        self.need_configuration(True)
-
         self.folder = folder
         self.folderGroupName = folderGroupName
         self.includeHidden = includeHidden
         self.compareIgnoreMtime = compareIgnoreMtime
 
+        self.fstype = None
         self.files = []
-
+        
     def initialize(self):
         return True
 
+    def is_configured(self, isSource, isTwoWay):
+        return Vfs.uri_exists(self.folder)
+
     def refresh(self):
         DataProvider.TwoWay.refresh(self)
+        #cache the filesystem type for speed
+        self.fstype = Vfs.uri_get_filesystem_type(self.folder)
+
         #scan the folder
         scanThread = Vfs.FolderScanner(self.folder, self.includeHidden)
         scanThread.start()
         scanThread.join()
-
         self.files = scanThread.get_uris()
 
     def put(self, vfsFile, overwrite, LUID=None):
@@ -213,14 +272,19 @@ class FolderTwoWay(DataProvider.TwoWay):
             newURI = self.folder+os.sep+vfsFile.get_filename()
         else:
             #Look for corresponding groups
+            relpath = vfsFile.get_relative_uri()
             if self.folderGroupName == vfsFile.group:
                 log.debug("FolderTwoWay: Found corresponding group")
                 #put in the folder
-                newURI = self.folder+vfsFile.relpath
+                newURI = self.folder+relpath
             else:
                 log.debug("FolderTwoWay: Recreating group %s --- %s --- %s" % (vfsFile._get_text_uri(),vfsFile.basePath,vfsFile.group))
                 #unknown. Store in the dir but recreate the group
-                newURI = self.folder+os.sep+os.path.join(vfsFile.group+vfsFile.relpath)
+                newURI = self.folder+os.sep+os.path.join(vfsFile.group+relpath)
+
+        #escape illegal filesystem characters
+        if self.fstype:
+            newURI = Vfs.uri_sanitize_for_filesystem(newURI, self.fstype)
 
         destFile = File.File(URI=newURI)
         comp = vfsFile.compare(
@@ -228,7 +292,10 @@ class FolderTwoWay(DataProvider.TwoWay):
                         sizeOnly=self.compareIgnoreMtime
                         )
         if overwrite or comp == DataType.COMPARISON_NEWER:
-            vfsFile.transfer(newURI, True)
+            try:
+                vfsFile.transfer(newURI, True)
+            except File.FileTransferError:
+                raise Exceptions.SyncronizeFatalError("Transfer Cancelled")
 
         return self.get(newURI).get_rid()
 
@@ -255,12 +322,13 @@ class FolderTwoWay(DataProvider.TwoWay):
     def finish(self, aborted, error, conflict):
         DataProvider.TwoWay.finish(self)
         self.files = []
+        #Save the .group file to the root of this volume (if it is removable)
+        save_removable_volume_group_file(self.folder, self.folderGroupName)
 
     def add(self, LUID):
         f = File.File(URI=LUID)
         if f.exists() and f.is_directory():
             self.folder = f._get_text_uri()
-            self.set_configured(True)
             return True
         return False
 
