@@ -48,7 +48,6 @@ class MainWindow:
         Constructs the mainwindow. Throws up a splash screen to cover 
         the most time consuming pieces
         """
-        gnome.init(conduit.APPNAME, conduit.APPVERSION, properties={gnome.PARAM_APP_DATADIR:'/usr/share'})
         gnome.ui.authentication_manager_init()        
 
         self.conduitApplication = conduitApplication
@@ -70,7 +69,8 @@ class MainWindow:
         
         dic = { "on_mainwindow_delete" : self.on_window_closed,
                 "on_mainwindow_state_event" : self.on_window_state_event,
-                "on_synchronize_activate" : self.on_synchronize_all_clicked,      
+                "on_synchronize_activate" : self.on_synchronize_all_clicked,
+                "on_cancel_activate" : self.on_cancel_all_clicked,  
                 "on_quit_activate" : self.on_window_closed,
                 "on_clear_canvas_activate" : self.on_clear_canvas,
                 "on_preferences_activate" : self.on_conduit_preferences,
@@ -79,7 +79,6 @@ class MainWindow:
                 "on_save1_activate" : self.save_settings,
                 None : None
                 }
-         
         self.widgets.signal_autoconnect(dic)
 
         #type converter and sync manager
@@ -96,9 +95,9 @@ class MainWindow:
                 gtk.widget_set_default_colormap(colormap)
         self.mainWindow.set_position(gtk.WIN_POS_CENTER)
         self.mainWindow.set_icon_name("conduit")
-        title = "%s" % conduit.APPNAME
+        title = "Conduit"
         if conduit.IS_DEVELOPMENT_VERSION:
-            title = title + " - %s (Development Version)" % conduit.APPVERSION
+            title = title + " - %s (Development Version)" % conduit.VERSION
         if not conduit.IS_INSTALLED:
             title = title + " - Running Uninstalled"
         self.mainWindow.set_title(title)
@@ -128,15 +127,8 @@ class MainWindow:
         #Set up the expander used for resolving sync conflicts
         self.conflictResolver = ConflictResolver.ConflictResolver(self.widgets)
 
-        #setup the module manager
-        self.moduleManager = moduleManager
-        self.dataproviderTreeModel.add_dataproviders(self.moduleManager.get_modules_by_type("source"))
-        self.dataproviderTreeModel.add_dataproviders(self.moduleManager.get_modules_by_type("sink"))
-        self.dataproviderTreeModel.add_dataproviders(self.moduleManager.get_modules_by_type("twoway"))
-        self.moduleManager.connect("dataprovider-available", self.on_dataprovider_available)
-        self.moduleManager.connect("dataprovider-unavailable", self.on_dataprovider_unavailable)
-
         #final GUI setup
+        self.cancelSyncButton = self.widgets.get_widget('cancel')
         self.hpane.set_position(conduit.GLOBALS.settings.get("gui_hpane_postion"))
         self.dataproviderTreeView.set_expand_rows()
         self.window_state = 0
@@ -175,13 +167,9 @@ class MainWindow:
         cond.connect("sync-completed", self.on_sync_completed)
         cond.connect("sync-conflict", self.conflictResolver.on_conflict)
 
-    def on_conduit_removed(self, syncset, cond):
-        pass
-
     def set_model(self, syncSet):
         self.syncSet = syncSet
         self.syncSet.connect("conduit-added", self.on_conduit_added)
-        self.syncSet.connect("conduit-removed", self.on_conduit_removed)
         self.canvas.set_sync_set(syncSet)
 
     def present(self):
@@ -208,33 +196,25 @@ class MainWindow:
         return (not minimized) and self.mainWindow.get_property('visible')
 
     def on_sync_started(self, thread):
-        log.debug("GUI got sync started")
+        self.cancelSyncButton.set_property("sensitive", True)
 
     def on_sync_completed(self, thread, aborted, error, conflict):
-        log.debug("GUI got sync completed")
+        self.cancelSyncButton.set_property(
+                "sensitive",
+                conduit.GLOBALS.syncManager.is_busy()
+                )
        
-    def on_dataprovider_available(self, loader, dataprovider):
-        """
-        Adds the new dataprovider to the treeview
-        """
-        if dataprovider.enabled == True:
-            self.dataproviderTreeModel.add_dataprovider(dataprovider)
-
-    def on_dataprovider_unavailable(self, unloader, dataprovider):
-        """
-        Removes the dataprovider from the treeview and replaces it with pending dataproviders
-        """
-        self.dataproviderTreeModel.remove_dataprovider(dataprovider)
-        
     def on_synchronize_all_clicked(self, widget):
         """
         Synchronize all valid conduits on the canvas
         """
-        for conduit in self.syncSet.get_all_conduits():
-            if conduit.datasource is not None and len(conduit.datasinks) > 0:
-                self.sync_manager.sync_conduit(conduit)
-            else:
-                log.info("Conduit must have a datasource and a datasink")        
+        self.conduitApplication.Synchronize()
+                
+    def on_cancel_all_clicked(self, widget):
+        """
+        Cancels all currently runnings syncs
+        """
+        self.conduitApplication.Cancel()
 
     def on_clear_canvas(self, widget):
         """
@@ -263,10 +243,10 @@ class MainWindow:
             converterListStore.append( (string,) )
         dataProviderListStore = gtk.ListStore( str, bool )
         #get all dataproviders
-        for i in self.moduleManager.get_modules_by_type("sink","source","twoway"):
+        for i in conduit.GLOBALS.moduleManager.get_modules_by_type("sink","source","twoway"):
             dataProviderListStore.append(("Name: %s\nDescription: %s)" % (i.name, i.description), True))
         #include files that could not be loaded
-        for f in self.moduleManager.invalidFiles:
+        for f in conduit.GLOBALS.moduleManager.invalidFiles:
             dataProviderListStore.append(("Error loading file: %s" % f, False))
 
         #construct the dialog
@@ -383,7 +363,16 @@ class MainWindow:
         """
         Display help
         """
-        gnome.help_display(conduit.APPNAME, None)
+        if conduit.IS_INSTALLED:
+            uri = "ghelp:conduit"
+        else:
+            #if we are not installed then launch the ghelp uri with a full path
+            uri = "ghelp:%s" % os.path.join(conduit.DIRECTORY,"help","C","conduit.xml")
+        log.debug("Launching help: %s" % uri)
+        gobject.spawn_async(
+                    argv=("xdg-open",uri),
+                    flags=gobject.SPAWN_SEARCH_PATH | gobject.SPAWN_STDOUT_TO_DEV_NULL | gobject.SPAWN_STDERR_TO_DEV_NULL
+                    )
 
     def on_window_state_event(self, widget, event):
         visible = self.is_visible()
@@ -424,11 +413,6 @@ class MainWindow:
         #DBus interface which will tidy up any pending running
         #non gui tasks
         if quit:
-            #FIXME: I want to do this call over DBus but this hangs. Why?
-            #sessionBus = dbus.SessionBus()
-            #obj = sessionBus.get_object(conduit.DBUS_IFACE, "/activate")
-            #conduitApp = dbus.Interface(obj, conduit.DBUS_IFACE)
-            #conduitApp.Quit()
             self.conduitApplication.Quit()
         
         
@@ -448,7 +432,7 @@ class MainWindow:
         #signal and NOT here
         if dataproviderKey != "":
             #Add a new instance if the dataprovider to the canvas.
-            new = self.moduleManager.get_module_wrapper_with_instance(dataproviderKey)
+            new = conduit.GLOBALS.moduleManager.get_module_wrapper_with_instance(dataproviderKey)
             self.canvas.add_dataprovider_to_canvas(dataproviderKey, new, x, y)
         
         context.finish(True, True, etime)
@@ -532,11 +516,19 @@ class SplashScreen:
 class AboutDialog(gtk.AboutDialog):
     def __init__(self):
         gtk.AboutDialog.__init__(self)
-        self.set_name(conduit.APPNAME)
-        self.set_version(conduit.APPVERSION)
+        self.set_name("Conduit")
+        self.set_version(conduit.VERSION)
         self.set_comments("Synchronisation for GNOME")
         self.set_website("http://www.conduit-project.org")
-        self.set_authors(["John Stowers","John Carr","Thomas Van Machelen","Jonny Lamb"])
+        self.set_authors([
+        		"John Stowers",
+        		"John Carr",
+        		"Thomas Van Machelen",
+        		"Jonny Lamb"])
+        self.set_artists([
+        		"John Stowers",
+        		"mejogid",
+        		"The Tango Project (http://tango.freedesktop.org)"])
         self.set_logo_icon_name("conduit")
 
 class StatusIcon(gtk.StatusIcon):
@@ -552,6 +544,7 @@ class StatusIcon(gtk.StatusIcon):
              <menubar name="Menubar">
               <menu action="Menu">
                <menuitem action="Sync"/>
+               <menuitem action="Cancel"/>
                <menuitem action="Quit"/>
                <separator/>
                <menuitem action="About"/>
@@ -561,7 +554,8 @@ class StatusIcon(gtk.StatusIcon):
         '''
         actions = [
             ('Menu',  None, 'Menu'),
-            ('Sync', gtk.STOCK_EXECUTE, _("_Synchronize"), None, _("Synchronize all dataproviders"), self.on_synchronize),
+            ('Sync', gtk.STOCK_EXECUTE, _("_Synchronize All"), None, _("Synchronizes All Groups"), self.on_synchronize),
+            ('Cancel', gtk.STOCK_CANCEL, _("_Cancel Synchronization"), None, _("Cancels Currently Synchronizing Groups"), self.on_cancel),
             ('Quit', gtk.STOCK_QUIT, _("_Quit"), None, _("Close Conduit"), self.on_quit),
             ('About', gtk.STOCK_ABOUT, _("_About"), None, _("About Conduit"), self.on_about)]
         ag = gtk.ActionGroup('Actions')
@@ -569,86 +563,80 @@ class StatusIcon(gtk.StatusIcon):
         self.manager = gtk.UIManager()
         self.manager.insert_action_group(ag, 0)
         self.manager.add_ui_from_string(menu)
-        self.menu = self.manager.get_widget('/Menubar/Menu/About').props.parent        
+        self.menu = self.manager.get_widget('/Menubar/Menu/About').props.parent
+        self.cancelButton = self.manager.get_widget('/Menubar/Menu/Cancel')   
         self.connect('popup-menu', self.on_popup_menu)
         self.connect('activate', self.on_click)
 
-        #start with the application icon
-        self._reset_states()
-        self._go_to_idle_state()
-        self.set_tooltip("Conduit")
-        self.set_visible(True)
-
-    def _reset_states(self):
-        self.running = 0
+        self.animating = False
+        self.check_animate = False
         self.conflict = False
         self.animated_idx = 0
         self.animated_icons = range(1,8)
 
-    def _go_to_idle_state(self):
+        #start with the application icon
+        self.cancelButton.set_property("sensitive", False)
         self.set_from_icon_name("conduit")
-        self.set_tooltip(_("Synchronization Complete"))
+        self.set_tooltip("Conduit")
+        self.set_visible(True)
 
-    def _go_to_conflict_state(self):
-        self.set_from_icon_name("dialog-error")
-        self.set_tooltip(_("Synchronization Error"))
-
-    def _go_to_running_state(self):
-        self.set_tooltip(_("Synchronizing"))
-        if self.animated_idx == self.animated_icons[-1]:
-            self.animated_idx = 1
-        else:
-            self.animated_idx += 1
-        self.set_from_icon_name("conduit-progress-%d" % self.animated_idx)
-        if self.running == 0:
-            if self.conflict:
-                self._go_to_conflict_state()
-                self._reset_states()
+    def _animate_icon_timeout(self):
+        #FIXME: When will gtk support animated gtk status icons?
+        if self.animating:
+            if self.animated_idx == self.animated_icons[-1]:
+                self.animated_idx = 1
             else:
-                self._go_to_idle_state()
-                self._reset_states()
-
-            return False
-        else:
+                self.animated_idx += 1
+                self.set_from_icon_name("conduit-progress-%d" % self.animated_idx)
+            # re-check animation?                
+            if self.check_animate:
+                self.animating =  conduit.GLOBALS.syncManager.is_busy()
+                self.check_animate = False
             return True
 
+        else: 
+            if self.conflict:
+                self.set_from_icon_name("dialog-error")
+                self.set_tooltip(_("Synchronization Error"))
+            else:
+                self.set_from_icon_name("conduit")
+                self.set_tooltip(_("Synchronization Complete"))
+            self.conflict = False
+            self.cancelButton.set_property("sensitive", False)
+            return False
+
     def on_conduit_added(self, syncset, cond):
         cond.connect("sync-started", self._on_sync_started)
         cond.connect("sync-completed", self._on_sync_completed)
         cond.connect("sync-conflict", self._on_sync_conflict)
-        #cond.connect("sync-progress", self._on_sync_progress)
-
+        
     def on_conduit_removed(self, syncset, cond):
         pass
 
     def _on_sync_started(self, cond):
-        self.running += 1
-        gobject.timeout_add(100, self._go_to_running_state)
-        log.debug("Icon got sync started")
+        if not self.animating:
+            self.animating = True
+            self.set_tooltip(_("Synchronizing"))
+            self.cancelButton.set_property("sensitive", True)
+            gobject.timeout_add(100, self._animate_icon_timeout)
 
     def _on_sync_completed(self, cond, aborted, error, conflict):
-        self.running -= 1
-        log.debug("Icon got sync completed %s (error: %s)" % (self.running, error))
+        # check need for animation on next iteration
+        self.check_animate = True
 
     def _on_sync_conflict(self, cond, conflict):
         self.conflict = True
-        log.debug("Icon got sync conflict")
 
     def on_synchronize(self, data):
-        #sessionBus = dbus.SessionBus()
-        #obj = sessionBus.get_object(conduit.DBUS_IFACE, "/activate")
-        #conduitApp = dbus.Interface(obj, conduit.DBUS_IFACE)
-        #conduitApp.Synchronize()
         self.conduitApplication.Synchronize()
+        
+    def on_cancel(self, data):
+        self.conduitApplication.Cancel()
 
     def on_popup_menu(self, status, button, time):
         self.menu.popup(None, None, None, button, time)
 
     def on_quit(self, data):
-        #sessionBus = dbus.SessionBus()
-        #obj = sessionBus.get_object(conduit.DBUS_IFACE, "/activate")
-        #conduitApp = dbus.Interface(obj, conduit.DBUS_IFACE)
-        #conduitApp.Quit()
         self.conduitApplication.Quit()
 
     def on_about(self, data):
